@@ -89,7 +89,6 @@ import com.openexchange.context.ContextService;
 import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
@@ -109,13 +108,13 @@ import com.openexchange.mail.api.AuthenticationFailureHandlerResult.Type;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.config.MailProperties;
-import com.openexchange.mail.config.MailProxyConfig;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.SecuritySettings;
 import com.openexchange.mail.dataobjects.compose.ComposeType;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
 import com.openexchange.mail.dataobjects.compose.ContentAware;
 import com.openexchange.mail.mime.HeaderCollection;
+import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.MimeHeaderNameChecker;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeMailExceptionCode;
@@ -133,7 +132,6 @@ import com.openexchange.mailaccount.Account;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.mailaccount.TransportAuth;
-import com.openexchange.net.HostList;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.net.ssl.exception.SSLExceptionCode;
@@ -150,6 +148,7 @@ import com.openexchange.smtp.filler.SMTPMessageFiller;
 import com.openexchange.smtp.services.Services;
 import com.openexchange.threadpool.AbstractTask;
 import com.openexchange.threadpool.ThreadPools;
+import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 import com.sun.mail.smtp.JavaSMTPTransport;
 import com.sun.mail.smtp.SMTPMessage;
@@ -177,7 +176,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
     static {
         try {
             staticHostName = InetAddress.getLocalHost().getCanonicalHostName();
-        } catch (final UnknownHostException e) {
+        } catch (UnknownHostException e) {
             staticHostName = "localhost";
             warnSpam = e;
         }
@@ -383,7 +382,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         }
     }
 
-    protected boolean checkRecipients(final Address[] recipients) throws OXException {
+    protected boolean checkRecipients(Address[] recipients) throws OXException {
         if ((recipients == null) || (recipients.length == 0)) {
             throw SMTPExceptionCode.MISSING_RECIPIENTS.create();
         }
@@ -419,7 +418,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                         }
                         try {
                             internetAddress.setPersonal("", "US-ASCII");
-                        } catch (final UnsupportedEncodingException e) {
+                        } catch (UnsupportedEncodingException e) {
                             LOG.trace("\"US-ASCII\" is not supported", e);
                             // Ignore as personal is cleared
                         }
@@ -437,28 +436,18 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         if (null == smtpSession) {
             synchronized (this) {
                 if (null == smtpSession) {
-                    final Properties smtpProps = SMTPSessionProperties.getDefaultSessionProperties();
-                    /*
-                     * Remove proxy settings for whitelisted hosts
-                     */
-                    HostList nonProxyHosts = MailProxyConfig.getInstance().getSmtpNonProxyHostList();
-                    if (nonProxyHosts.contains(smtpConfig.getSmtpServerAddress())) {
-                        smtpProps.remove("mail.smtp.proxy.host");
-                        smtpProps.remove("mail.smtp.proxy.port");
-                        smtpProps.remove("mail.smtps.proxy.host");
-                        smtpProps.remove("mail.smtps.proxy.port");
-                    }
+                    Properties smtpProps = SMTPSessionProperties.getDefaultSessionProperties();
                     smtpProps.put("mail.smtp.class", JavaSMTPTransport.class.getName());
                     smtpProps.put("com.openexchange.mail.maxMailSize", Long.toString(getMaxMailSize()));
 
                     /*
                      * Set properties
                      */
-                    final ISMTPProperties smtpProperties = smtpConfig.getSMTPProperties();
+                    ISMTPProperties smtpProperties = smtpConfig.getSMTPProperties();
                     /*
                      * Check for Kerberos subject
                      */
-                    final boolean kerberosAuth = isKerberosAuth();
+                    boolean kerberosAuth = isKerberosAuth();
                     if (isKerberosAuth()) {
                         smtpProps.put("mail.smtp.auth", "true");
                         smtpProps.put("mail.smtp.sasl.enable", "true");
@@ -470,7 +459,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                     /*
                      * Localhost, & timeouts
                      */
-                    final String smtpLocalhost = smtpProperties.getSmtpLocalhost();
+                    String smtpLocalhost = smtpProperties.getSmtpLocalhost();
                     if (smtpLocalhost != null) {
                         smtpProps.put("mail.smtp.localhost", smtpLocalhost);
                     }
@@ -494,7 +483,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                     } else if (AuthType.OAUTHBEARER == smtpConfig.getAuthType()) {
                         smtpProps.put("mail.smtp.auth.mechanisms", "OAUTHBEARER");
                     } else {
-                        smtpProps.put("mail.imap.auth.mechanisms", "LOGIN PLAIN DIGEST-MD5 NTLM");
+                        smtpProps.put("mail.smtp.auth.mechanisms", "LOGIN PLAIN DIGEST-MD5 NTLM");
                     }
                     /*
                      * Check if a secure SMTP connection should be established
@@ -560,7 +549,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                                 // No SSL demanded and SMTP server seems not to support TLS
                                 throw MailExceptionCode.NON_SECURE_DENIED.create(smtpConfig.getServer());
                             }
-                        } catch (final IOException e) {
+                        } catch (IOException e) {
                             LOG.trace("Failed to determine SMTP server capabilities", e);
                             smtpProps.put("mail.smtp.starttls.enable", "true");
                         }
@@ -723,7 +712,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                 if (isKerberosAuth()) {
                     try {
                         Subject.doAs(kerberosSubject, new SaslSmtpLoginAction(transport, server, port, login, password));
-                    } catch (final PrivilegedActionException e) {
+                    } catch (PrivilegedActionException e) {
                         handlePrivilegedActionException(e);
                     }
                 } else {
@@ -880,7 +869,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
              */
             try {
                 checkMimeVersionHeader(mimeMessage);
-            } catch (final Exception e) {
+            } catch (Exception e) {
                 LOG.warn("Could not check for proper usage of \"MIME-Version\" header according to RFC2045.", e);
             }
         }
@@ -1024,7 +1013,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                 exception = e;
                 Exception nextException = e.getNextException();
                 if (nextException instanceof IOException) {
-                    if (nextException.getMessage().equals("Maximum message size is exceeded.")) {
+                    if ("Maximum message size is exceeded.".equals(nextException.getMessage())) {
                         throw MailExceptionCode.MAX_MESSAGE_SIZE_EXCEEDED.create(getSize(getMaxMailSize(), 0, false, true));
                     }
                 }
@@ -1109,7 +1098,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         try {
             SMTPConfig smtpConfig = getTransportConfig();
             transport = getSMTPSession(smtpConfig, smtpConfig.isRequireTls()).getTransport(SMTP);
-        } catch (final NoSuchProviderException e) {
+        } catch (NoSuchProviderException e) {
             throw MimeMailException.handleMessagingException(e);
         }
 
@@ -1122,7 +1111,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
             if (close) {
                 try {
                     transport.close();
-                } catch (final MessagingException e) {
+                } catch (MessagingException e) {
                     LOG.error("Closing SMTP transport failed.", e);
                 }
             }
@@ -1164,7 +1153,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
                         smtpFiller.setAccountId(accountId);
                         smtpFiller.setCommonHeaders(mimeMessage);
                     }
-                } catch (final Exception e) {
+                } catch (Exception e) {
                     LOG.trace("Failed to extract MIME message from {} instance", ContentAware.class.getName(), e);
                     mimeMessage = null;
                 }
@@ -1220,9 +1209,9 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
 
             MimeMessage sentMimeMessage = sendMimeMessage(mimeMessage, allRecipientz, mtaStatusInfo, composedMail.getSecuritySettings());
             return MimeMessageConverter.convertMessage(sentMimeMessage);
-        } catch (final MessagingException e) {
+        } catch (MessagingException e) {
             throw handleMessagingException(e, smtpConfig);
-        } catch (final IOException e) {
+        } catch (IOException e) {
             throw SMTPExceptionCode.IO_ERROR.create(e, e.getMessage());
         }
     }
@@ -1263,7 +1252,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
             }
 
             return MimeMessageConverter.convertMessage(smtpMessage);
-        } catch (final MessagingException e) {
+        } catch (MessagingException e) {
             throw MimeMailException.handleMessagingException(e, smtpConfig, session);
         }
     }
@@ -1305,7 +1294,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
             if (!poisoned) {
                 transport(smtpMessage, recipients, getSMTPSession(smtpConfig), smtpConfig);
             }
-        } catch (final MessagingException e) {
+        } catch (MessagingException e) {
             throw MimeMailException.handleMessagingException(e, smtpConfig, session);
         } finally {
             Streams.close(stream);
@@ -1319,7 +1308,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         try {
             smtpMessage = new SMTPMessage(getSMTPSession(), MimeHeaderNameChecker.sanitizeHeaderNames(asciiBytes));
             smtpMessage.removeHeader("x-original-headers");
-        } catch (final MessagingException e) {
+        } catch (MessagingException e) {
             throw handleMessagingException(e, smtpConfig);
         }
 
@@ -1334,7 +1323,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         try {
             smtpMessage = new SMTPMessage(getSMTPSession(), stream);
             smtpMessage.removeHeader("x-original-headers");
-        } catch (final MessagingException e) {
+        } catch (MessagingException e) {
             throw handleMessagingException(e, smtpConfig);
         }
 
@@ -1352,6 +1341,7 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
             // Check recipients
             Address[] recipients = allRecipients == null ? mimeMessage.getAllRecipients() : allRecipients;
             processAddressHeader(mimeMessage);
+            mimeMessage.removeHeader(MessageHeaders.HDR_X_OX_NO_REPLY_PERSONAL);
 
             // Save changes
             saveChangesSafe(mimeMessage, true);
